@@ -605,7 +605,6 @@ class varsShare:
         else:
             defaultAti = "radeon"
         defaultDriver = {
-            'vesa':'vesa',
             'nvidia':defaultNvidia,
             'ati':defaultAti,
             'intel':'intel',
@@ -616,7 +615,7 @@ class varsShare:
             defaultDriver[hr_video] in drivers_list:
             return defaultDriver[hr_video]
         else:
-            return "vesa"
+            return "other"
 
     def getKernelUid(self,device):
         """Get Kernel UID by UUID of device"""
